<?php

define('DB_DRIVER', 'mysql');
define('DB_USERNAME', 'root');
define('DB_PASSWORD', 'kanboard');
define('DB_HOSTNAME', '127.0.0.1');
define('DB_NAME', 'kanboard');

define('DEBUG', true);
define('LOG_DRIVER', 'stderr');

define('API_AUTHENTICATION_TOKEN', 'test');
